Cheetah.Tests.NameMapper module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Tests.NameMapper module

class `Cheetah.Tests.NameMapper.` `DummyClass`

  Bases: `object`

  `classVar1` = 123
  `meth`(arg='arff')
  `meth1`(arg='doo')
  `meth2`(arg1='a1', arg2='a2')
  `meth3`()

    Tests a bug that Jeff Johnson reported on Oct 1, 2001

class `Cheetah.Tests.NameMapper.` `DummyClassGetAttrRaises`

  Bases: `object`

class `Cheetah.Tests.NameMapper.` `MapBuiltins`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_int`()

class `Cheetah.Tests.NameMapper.` `NameMapperTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `VFN`(name, autocall=True)
  `VFS`(searchList, name, autocall=True)
  `check`(name)
  `failureException`

    alias of `NotFound`

  `get`(name, autocall=True)
  `namespace`()

class `Cheetah.Tests.NameMapper.` `VFF`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFN`

  `get`(name, autocall=True)
  `setUp`()

    Mod some of the data

  `test_VFF_1`()

    Builtins

class `Cheetah.Tests.NameMapper.` `VFFSL`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFS`

  `VFFSL`(searchList, name, autocall=True)
  `get`(name, autocall=True)
  `setUp`()

    Mod some of the data

class `Cheetah.Tests.NameMapper.` `VFFSL_2`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFFSL`

class `Cheetah.Tests.NameMapper.` `VFFSL_3`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFFSL`

class `Cheetah.Tests.NameMapper.` `VFFSL_4`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFFSL`

class `Cheetah.Tests.NameMapper.` `VFN`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.NameMapperTest`

  `test1`()

    string in dict lookup

  `test10`()

    aFunc in dict lookup in a loop

  `test11`()

    aMeth in dict lookup

  `test12`()

    aMeth in dict lookup in a loop

  `test13`()

    aMeth in dict lookup

  `test14`()

    aMeth in dict lookup in a loop

  `test15`()

    anObj in dict lookup

  `test16`()

    anObj in dict lookup in a loop

  `test17`()

    aDict in dict lookup

  `test18`()

    aDict in dict lookup in a loop

  `test19`()

    aClass.classVar1 in dict lookup

  `test2`()

    string in dict lookup in a loop

  `test20`()

    aClass.classVar1 in dict lookup in a loop

  `test23`()

    anObj.instanceVar1 in dict lookup

  `test24`()

    anObj.instanceVar1 in dict lookup in a loop

  `test27`()

    anObj.meth1 in dict lookup

  `test28`()

    anObj.meth1 in dict lookup in a loop

  `test29`()

    aDict.one in dict lookup

  `test3`()

    int in dict lookup

  `test30`()

    aDict.one in dict lookup in a loop

  `test31`()

    aDict.nestedDict in dict lookup

  `test32`()

    aDict.nestedDict in dict lookup in a loop

  `test33`()

    aDict.nestedDict.one in dict lookup

  `test34`()

    aDict.nestedDict.one in dict lookup in a loop

  `test35`()

    aDict.nestedFunc in dict lookup

  `test36`()

    aDict.nestedFunc in dict lookup in a loop

  `test37`()

    aDict.nestedFunc in dict lookup - without autocalling

  `test38`()

    aDict.nestedFunc in dict lookup in a loop - without autocalling

  `test39`()

    aMeth in dict lookup - without autocalling

  `test4`()

    int in dict lookup in a loop

  `test40`()

    aMeth in dict lookup in a loop - without autocalling

  `test41`()

    anObj.meth3 in dict lookup

  `test42`()

    aMeth in dict lookup in a loop

  `test43`()

    NotFound test

  `test44`()

    NotFound test in a loop

  `test45`()

    Other exception from meth test

  `test46`()

    Other exception from meth test in a loop

  `test47`()

    None in dict lookup

  `test48`()

    None in dict lookup in a loop

  `test49`()

    EmptyString in dict lookup

  `test5`()

    float in dict lookup

  `test50`()

    EmptyString in dict lookup in a loop

  `test51`()

    Other exception from func test

  `test52`()

    Other exception from func test in a loop

  `test53`()

    Other exception from func test

  `test54`()

    Other exception from func test in a loop

  `test55`()

    aDict.nestedDict.aClass in dict lookup

  `test56`()

    aDict.nestedDict.aClass in dict lookup in a loop

  `test57`()

    aDict.nestedDict.aClass in dict lookup - without autocalling

  `test58`()

    aDict.nestedDict.aClass in dict lookup in a loop - without autocalling

  `test59`()

    Other exception from func test – but without autocalling shouldn’t raise

  `test6`()

    float in dict lookup in a loop

  `test60`()

    Other exception from func test in a loop – but without autocalling shouldn’t raise

  `test61`()

    Accessing attribute where __getattr__ raises shouldn’t segfault if something follows it

  `test7`()

    class in dict lookup

  `test8`()

    class in dict lookup in a loop

  `test9`()

    aFunc in dict lookup

class `Cheetah.Tests.NameMapper.` `VFS`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFN`

  `get`(name, autocall=True)
  `searchList`()
  `searchListGenerator`()

class `Cheetah.Tests.NameMapper.` `VFS_2namespaces`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFS`

class `Cheetah.Tests.NameMapper.` `VFS_3namespaces`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFS`

class `Cheetah.Tests.NameMapper.` `VFS_4namespaces`(methodName='runTest')

  Bases: `Cheetah.Tests.NameMapper.VFS`

`Cheetah.Tests.NameMapper.` `aClass`

  alias of `DummyClass`

`Cheetah.Tests.NameMapper.` `aFunc`(arg='Scooby')

`Cheetah.Tests.NameMapper.` `dummyFunc`(arg='Scooby')

`Cheetah.Tests.NameMapper.` `funcThatRaises`()